package com.gmh.utils;

import cn.hutool.core.util.StrUtil;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

import java.io.*;
import java.nio.file.Files;

/**
 * POI Excel工具类
 * created on 2020/5/28 10:08
 *
 * @author puhaiyang
 */
public class POIExcelUtil {

    public static void main(String[] args) throws IOException {
        File file = new File("C:\\Users\\xxche\\Desktop\\20221106_test_excel\\附件3.继续教育证明.xls");
        Workbook workbook = batchCloneSheet(file, 0, 50);
        try {
            FileOutputStream out = new FileOutputStream("C:\\Users\\xxche\\Desktop\\20221106_test_excel\\附件3.继续教育证明222.xls");
            out.flush();
            workbook.write(out);
            out.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public static Workbook cloneSheet(Workbook workbook, String srcSheetName, String destSheetName) {
        int index = workbook.getSheetIndex(srcSheetName);
        return cloneSheet(workbook, index, destSheetName);
    }

    public static Workbook cloneSheet(Workbook workbook, Integer index, String destSheetName) {
        //克隆一个新的sheet
        Sheet newSheet = workbook.cloneSheet(index);
        int sheetIndex = workbook.getSheetIndex(newSheet);
        workbook.setSheetName(sheetIndex, destSheetName);
        return workbook;
    }

    public static Workbook cloneSheet(File excelFile, Integer index, String destSheetName) throws IOException {
        Workbook workbook = readExcelFromFile(excelFile);
        return cloneSheet(workbook, index, destSheetName);
    }

    /**
     * 复制多个sheet
     *
     * @param workbook  workbook
     * @param index     起始sheet
     * @param total     复制多个sheet
     */
    public static Workbook batchCloneSheet(Workbook workbook, Integer index, Integer total) throws IOException {
        for (int i = 0; i < total; i++) {
            //克隆一个新的sheet
            Sheet newSheet = workbook.cloneSheet(index);
            int sheetIndex = workbook.getSheetIndex(newSheet);
            workbook.setSheetName(sheetIndex, String.valueOf(i + 1));
        }
        workbook.removeSheetAt(index);
        return workbook;
    }

    public static Workbook batchCloneSheet(File excelFile, Integer index, Integer total) throws IOException {
        Workbook workbook = readExcelFromFile(excelFile);
        return batchCloneSheet(workbook, index, total);
    }

    //读取excel
    public static Workbook readExcelFromFile(File file) throws IOException {
        if (file == null) {
            throw new RuntimeException("文件为空");
        }
        return readExcelFromInputStream(Files.newInputStream(file.toPath()), file.getName());
    }

    public static Workbook readExcelFromInputStream(InputStream inputStream, String fileName) throws IOException {
        if (StrUtil.isBlank(fileName)) {
            throw new RuntimeException("文件格式错误");
        }
        String[] split = fileName.split("\\.");
        if (split.length == 0 || split.length == 1) {
            throw new RuntimeException("文件格式错误");
        }
        String suffix = split[split.length - 1];
        if ("xls".equals(suffix)) {
            return new HSSFWorkbook(inputStream);
        } else if ("xlsx".equals(suffix)) {
            return new XSSFWorkbook(inputStream);
        } else {
            throw new RuntimeException("文件格式错误");
        }
    }

    public static String getStringCellValExcludeBlank(Cell cell) {
        cell.setCellType(Cell.CELL_TYPE_STRING);
        return cell.getStringCellValue().replaceAll("\\s*", "");
    }
}